@@ -1,12 +1,15 @@
 package Aw::Admin::LogConfig;
 
-use strict;
-use vars qw($VERSION);
 
-$VERSION = '0.1';
+BEGIN
+{
+	use strict;
+	use vars qw($VERSION);
 
-require Aw::Admin;
+	$VERSION = '0.2';
 
+	require Aw::Admin;
+}
 
 
 sub getOutput
@@ -55,7 +58,7 @@ Enhanced interface for the Aw/Client.xs LogConfig methods.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
+Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
 
 =head1 SEE ALSO
 
