@@ -1,15 +1,18 @@
 package Aw::Admin::TypeDef;
 
-use strict;
-use vars qw($VERSION);
 
-$VERSION = '0.1';
+BEGIN
+{
+	use strict;
+	use vars qw($VERSION);
 
-require Aw::Admin;
+	$VERSION = '0.2';
+
+	require Aw::Admin;
+}
 
 
-
-sug getFieldNames
+sub getFieldNames
 {
 	my $result = Aw::Admin::TypeDef::getFieldNamesRef ( @_ )
 	( wantarray ) ? @{ $result } : $result ;
@@ -44,7 +47,7 @@ Enhanced interface for the Aw/Admin.xs TypeDef methods.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
+Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
 
 =head1 SEE ALSO
 
