@@ -1,10 +1,13 @@
 package Aw::ConnectionDescriptor;
 
-use strict;
-use vars qw($VERSION);
 
-$VERSION = '0.1';
+BEGIN
+{
+	use strict;
+	use vars qw($VERSION);
 
+	$VERSION = '0.2';
+}
 
 
 sub getSSLCertificate
@@ -58,7 +61,7 @@ Enhanced interface for the Aw.xs Connection Descriptor methods.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
+Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
 
 =head1 SEE ALSO
 
